==> enterprisemodules-easy_type-2.37.0.tar.gz: enterprisemodules-easy_type-2.37.0/lib/puppet/type/cleanup.rb <==
#
# See the file "LICENSE" for the full license governing this code.
#
# frozen_string_literal: true

require 'easy_type'

Puppet::Type.newtype(:cleanup) do
  #
  # We (re)define a class here to ensure that the usage of class method doen't
  # create a warning. The way we have defined it now it is in the same lexical
  # scope. See [here](https://www.honeybadger.io/blog/lexical-scoping-and-ruby-class-variables/)
  #
  class Puppet::Type::Cleanup

    @doc = <<-DOC
      This type allows you to specify files to cleanup at the end of the Puppet run. 

      You don't need to be very careful where you place the cleanup, because the cleanup will
      only be done when **all** of the Puppet run processing has been done.

      This is an ideal replacement for all of the `exec { '/bin/rm -f xxx:}` resources you had before.

      Here is an example on how to use it:

          cleanup { '/tmp/temporary_files':}

      This will cleanup (== remove) all files in the directory `/tmp/tempoirary_files`. 

      You can use the cleanup resource both for individual files and directories. When you
      specify a directory; the directory including any subdirectories will be removed.

    DOC

    newparam(:name) do
      isnamevar

      desc <<-DESC
        the name of the cleanup resource.
      DESC
    end

    newparam(:file_name) do
      include EasyType

      data_type('Stdlib::Absolutefile')

      desc <<-DESC
        the file name of the file you want to cleanup. If this is not specified, Puppet will use 
        the title as the file name.
      DESC
    end

    newparam(:loglevel) do
      defaultto :debug
      newvalues(:debug, :info, :notice, :warning, :err, :alert, :emerg, :crit)
    end

    def scoped_log(scope, msg)
      scope.send(scope[:loglevel], msg)
    end

    validate do
      return unless scheduled?

      if defined?(@@files_to_cleanup).nil?
        @@files_to_cleanup = []
        at_exit do
          log"Cleaning files marked for cleanup."
          @@files_to_cleanup.each do |pair|
            file = pair[:name]
            scope = pair[:scope]
            if ::File.exists?(file)
              scoped_log(scope, "cleaning file/directory #{file}...")
              FileUtils.rm_rf(file)
            else
              scoped_log(scope, "File #{file} not found, skipping cleanup...")
            end
          end
        end
      end
      actual_file_name = self[:file_name] ? self[:file_name] : self[:name]
      @@files_to_cleanup << {:name => actual_file_name, :scope => self}
    end

    def scheduled?
      name = self[:schedule]
      return true if name.to_s == ''
      scheduler = catalog.resource(:schedule, name) || raise(_('Could not find schedule %{name}') % { name: name })
      scheduler.match?
    end
  end
end

==> enterprisemodules-easy_type-2.40.0.tar.gz: enterprisemodules-easy_type-2.40.0/lib/puppet/type/cleanup.rb <==
#
# See the file "LICENSE" for the full license governing this code.
#
# frozen_string_literal: true

require 'easy_type'

Puppet::Type.newtype(:cleanup) do
  #
  # We (re)define a class here to ensure that the usage of class method doen't
  # create a warning. The way we have defined it now it is in the same lexical
  # scope. See [here](https://www.honeybadger.io/blog/lexical-scoping-and-ruby-class-variables/)
  #
  class Puppet::Type::Cleanup

    @doc = <<-DOC
      This type allows you to specify files to cleanup at the end of the Puppet run. 

      You don't need to be very careful where you place the cleanup, because the cleanup will
      only be done when **all** of the Puppet run processing has been done.

      This is an ideal replacement for all of the `exec { '/bin/rm -f xxx:}` resources you had before.

      Here is an example on how to use it:

          cleanup { '/tmp/temporary_files':}

      This will cleanup (== remove) all files in the directory `/tmp/tempoirary_files`. 

      You can use the cleanup resource both for individual files and directories. When you
      specify a directory; the directory including any subdirectories will be removed.

    DOC

    newparam(:name) do
      isnamevar

      desc <<-DESC
        the name of the cleanup resource.
      DESC
    end

    newparam(:file_name) do
      include EasyType

      data_type('Stdlib::Absolutefile')

      desc <<-DESC
        the file name(s) of the file you want to cleanup. If this is not specified, Puppet will use 
        the title as the file name.
      DESC
    end

    newparam(:loglevel) do
      defaultto :debug
      newvalues(:debug, :info, :notice, :warning, :err, :alert, :emerg, :crit)
    end

    def scoped_log(scope, msg)
      scope.send(scope[:loglevel], msg)
    end

    validate do
      return unless scheduled?

      if defined?(@@files_to_cleanup).nil?
        @@files_to_cleanup = []
        at_exit do
          log"Cleaning files marked for cleanup."
          @@files_to_cleanup.each do |pair|
            file = pair[:name]
            scope = pair[:scope]
            if ::File.exists?(file)
              scoped_log(scope, "cleaning file/directory #{file}...")
              FileUtils.rm_rf(file)
            else
              scoped_log(scope, "File #{file} not found, skipping cleanup...")
            end
          end
        end
      end
      actual_file_name = self[:file_name] ? self[:file_name] : self[:name]
      Array(actual_file_name).each do | file_name |
        @@files_to_cleanup << {:name => file_name, :scope => self}
      end
    end

    def scheduled?
      name = self[:schedule]
      return true if name.to_s == ''
      scheduler = catalog.resource(:schedule, name) || raise(_('Could not find schedule %{name}') % { name: name })
      scheduler.match?
    end
  end
end
